doapfiend

Package doapfiend |
[hide private]
[frames] | no frames]

# Source Code for Package doapfiend

     1
     2  #pylint: disable-msg=C0103
     3  """
     4  doapfiend
     5  =========
     6
     7  U{http://trac.doapspace.org/doapfiend}
     8
     9  Description
    10  -----------
    11  doapfiend is a command-line client and library for querying, creating and
    12  displaying DOAP (Description of a Project) RDF profiles.
    13
    14  doapfiend uses RDFAlchemy and rdflib to parse and serialize DOAP.
    15
    16  Plugins
    17  -------
    18  Plugins can be written for editing DOAP, scraping websites and creating DOAP,
    19  searching for DOAP in SPARQL endpoints, displaying DOAP in various formats such
    20  as HTML etc.
    21
    22
    23  """
    24
    25
    26  #Hack to get around warning in RDFAlchemy, bug filed upstream
    27  import logging
    28  log = logging.getLogger()
    29  log.setLevel(logging.ERROR)
    30
    31  __docformat__ = 'epytext'
    32  __version__ = '0.3.1'
    33  __author__ = 'Rob Cakebread <rob@doapspace.org>'
    34  __copyright__ = '(C) 2007-2008 Rob Cakebread'
    35  __license__ = 'BSD-2'
    36